@@ -47,6 +47,13 @@ class classySpacyZeroShotExternal(object):
         return doc
 
     def set_pred_results_for_doc(self, doc: Doc):
+        """
+        It takes a spaCy Doc object, runs it through the pipeline, and then adds the predictions to the Doc object
+
+        :param doc: Doc
+        :type doc: Doc
+        :return: A list of dictionaries.
+        """
         pred_results = self.pipeline([sent.text for sent in list(doc.sents)], self.data)
         pred_results = [self.format_prediction(pred) for pred in pred_results]
         for sent, pred in zip(doc.sents, pred_results):
@@ -94,4 +101,11 @@ class classySpacyZeroShotExternal(object):
 
     @staticmethod
     def format_prediction(prediction):
+        """
+        It takes a prediction dictionary and returns a list of dictionaries, where each dictionary has a single key-value
+        pair
+
+        :param prediction: The prediction returned by the model
+        :return: A list of dictionaries.
+        """
         return [{label: score} for label, score in zip(prediction["labels"], prediction["scores"])]
